@@ -30,7 +30,7 @@ our @EXPORT_OK = qw (
 
 ## Version of Unicode::Peek module
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 $VERSION = eval $VERSION;
 
 ## Load necessary modules
@@ -56,9 +56,14 @@ my @unicodes = ( 'UCS-2',
 		 'UTF-32BE',
 		 'UTF-32LE' );
 
-sub _checkUnicode {
+sub _checkSubroutineParameters {
+    croak "Please pass only two parameters '@_'"
+	if scalar @_ != 2;
+
     croak "Unknown encoding format '$_[0]'"
 	unless (grep { /$_[0]/ } @unicodes);
+
+    return $_[0], $_[1];
 }
 
 sub _ascii2hex {
@@ -70,8 +75,7 @@ sub _hex2ascii {
 }
 
 sub hexDumperOutput {
-    _checkUnicode($_[0]);
-    my ( $unicodeFormat , $data ) = @_;
+    my ( $unicodeFormat , $data ) = _checkSubroutineParameters(@_);
     my $hexString = ascii2hexEncode( $unicodeFormat , $data );
     # trim leading and trailing white space
     # split string every two characters
@@ -85,22 +89,19 @@ sub hexDumperOutput {
 }
 
 sub hexDumperInput {
-    _checkUnicode($_[0]);
-    my ( $unicodeFormat , $arrayRef ) = @_;
+    my ( $unicodeFormat , $arrayRef ) = _checkSubroutineParameters(@_);
     my $hexString = join('', split(/ /, join('', @$arrayRef)));
     return hex2ascciiDecode($unicodeFormat, $hexString);
 }
 
 sub ascii2hexEncode {
-    _checkUnicode($_[0]);
-    my ( $unicodeFormat , $data ) = @_;
+    my ( $unicodeFormat , $data ) = _checkSubroutineParameters(@_);
     my $octets = encode( $unicodeFormat , $data );
     return _ascii2hex( $octets );
 }
 
 sub hex2ascciiDecode {
-    _checkUnicode($_[0]);
-    my ( $unicodeFormat , $data ) = @_;
+    my ( $unicodeFormat , $data ) = _checkSubroutineParameters(@_);
     my $hex2ascciiString = _hex2ascii( $data );
     return decode( $unicodeFormat , $hex2ascciiString );
 }
@@ -117,7 +118,7 @@ __END__
 
 =head1 VERSION
 
-    Version 0.05
+    Version 0.06
 
 
 =head1 SYNOPSIS
@@ -151,7 +152,7 @@ __END__
 
 This module exports four methods (ascii2hexEncode, hex2ascciiDecode, hexDumperOutput
     and hexDumperInput). All methods support 14 different encoding and decoding formats.
-    The module has been tested with multiple languages with complex characters, but not
+cd    The module has been tested with multiple languages with complex characters, but not
     with all known languages in the planet. So far as many languages have been tested all
     characters where encoded / decoded correctly.
 
@@ -412,6 +413,6 @@ Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
 =head1 CHANGE LOG
 
     $Log: Peek.pm,v $
-    Revision 0.05  2017/09/26 12:13:21 (UCT) Thanos
+    Revision 0.06  2017/09/27 12:13:21 (UCT) Thanos
 
 =cut
